==> jc-1.4.0.tar.gz: java/security/AlgorithmParameterGeneratorSpi.h <==
// public abstract class java.security.AlgorithmParameterGeneratorSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d641d91cd6167b5d java_security_AlgorithmParameterGeneratorSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_AlgorithmParameterGeneratorSpi_H_
#define _JC_java_security_AlgorithmParameterGeneratorSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_AlgorithmParameters$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_java_security_AlgorithmParameterGeneratorSpi$sub_refs	_jc_java_security_AlgorithmParameterGeneratorSpi$sub_refs;
typedef struct _jc_java_security_AlgorithmParameterGeneratorSpi$sub_nonrefs	_jc_java_security_AlgorithmParameterGeneratorSpi$sub_nonrefs;
typedef struct _jc_java_security_AlgorithmParameterGeneratorSpi$refs	_jc_java_security_AlgorithmParameterGeneratorSpi$refs;
typedef struct _jc_java_security_AlgorithmParameterGeneratorSpi$nonrefs	_jc_java_security_AlgorithmParameterGeneratorSpi$nonrefs;
typedef struct _jc_java_security_AlgorithmParameterGeneratorSpi$object	_jc_java_security_AlgorithmParameterGeneratorSpi$object;

typedef const struct _jc_java_security_AlgorithmParameterGeneratorSpi$vmethods	_jc_java_security_AlgorithmParameterGeneratorSpi$vmethods;
typedef const struct _jc_java_security_AlgorithmParameterGeneratorSpi$vtable	_jc_java_security_AlgorithmParameterGeneratorSpi$vtable;
typedef const struct _jc_java_security_AlgorithmParameterGeneratorSpi$vtype	_jc_java_security_AlgorithmParameterGeneratorSpi$vtype;

// Constructors
extern void _jc_java_security_AlgorithmParameterGeneratorSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *);

// Virtual methods
extern struct _jc_java_security_AlgorithmParameters$object *_jc_java_security_AlgorithmParameterGeneratorSpi$method$engineGenerateParameters$c500aa80c3b5d11e(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *);
extern void _jc_java_security_AlgorithmParameterGeneratorSpi$method$engineInit$ce17ad6b3fc98d82(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *);
extern void _jc_java_security_AlgorithmParameterGeneratorSpi$method$engineInit$5af33bc7d4d69573(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_AlgorithmParameterGeneratorSpi$method_info$engineGenerateParameters$c500aa80c3b5d11e;
extern _jc_method _jc_java_security_AlgorithmParameterGeneratorSpi$method_info$engineInit$ce17ad6b3fc98d82;
extern _jc_method _jc_java_security_AlgorithmParameterGeneratorSpi$method_info$engineInit$5af33bc7d4d69573;

// Virtual methods structure
struct _jc_java_security_AlgorithmParameterGeneratorSpi$vmethods {
	struct _jc_java_security_AlgorithmParameters$object	*(*engineGenerateParameters$c500aa80c3b5d11e)(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *);
	void	(*engineInit$ce17ad6b3fc98d82)(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *);
	void	(*engineInit$5af33bc7d4d69573)(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
};

// Vtable
struct _jc_java_security_AlgorithmParameterGeneratorSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_AlgorithmParameterGeneratorSpi$vmethods	java_security_AlgorithmParameterGeneratorSpi;
};

// Vtype
struct _jc_java_security_AlgorithmParameterGeneratorSpi$vtype {
	_jc_type			type;
	_jc_java_security_AlgorithmParameterGeneratorSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AlgorithmParameterGeneratorSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_AlgorithmParameterGeneratorSpi$refs {
    _jc_java_security_AlgorithmParameterGeneratorSpi$sub_refs	java_security_AlgorithmParameterGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AlgorithmParameterGeneratorSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_AlgorithmParameterGeneratorSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_AlgorithmParameterGeneratorSpi$sub_nonrefs	java_security_AlgorithmParameterGeneratorSpi;
};

// Object instance structure
struct _jc_java_security_AlgorithmParameterGeneratorSpi$object {
	_jc_java_security_AlgorithmParameterGeneratorSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AlgorithmParameterGeneratorSpi$vtype	*vtype;
	_jc_java_security_AlgorithmParameterGeneratorSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AlgorithmParameterGeneratorSpi$vtype _jc_java_security_AlgorithmParameterGeneratorSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AlgorithmParameterGeneratorSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AlgorithmParameterGeneratorSpi$class_object;

#endif	/* _JC_java_security_AlgorithmParameterGeneratorSpi_H_ */

==> jc-1.4.6.tar.gz: java/security/AlgorithmParameterGeneratorSpi.h <==
// public abstract class java.security.AlgorithmParameterGeneratorSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d641d91cd6167b5d java_security_AlgorithmParameterGeneratorSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_AlgorithmParameterGeneratorSpi_H_
#define _JC_java_security_AlgorithmParameterGeneratorSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_AlgorithmParameters$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_java_security_AlgorithmParameterGeneratorSpi$sub_refs	_jc_java_security_AlgorithmParameterGeneratorSpi$sub_refs;
typedef struct _jc_java_security_AlgorithmParameterGeneratorSpi$sub_nonrefs	_jc_java_security_AlgorithmParameterGeneratorSpi$sub_nonrefs;
typedef struct _jc_java_security_AlgorithmParameterGeneratorSpi$refs	_jc_java_security_AlgorithmParameterGeneratorSpi$refs;
typedef struct _jc_java_security_AlgorithmParameterGeneratorSpi$nonrefs	_jc_java_security_AlgorithmParameterGeneratorSpi$nonrefs;
typedef struct _jc_java_security_AlgorithmParameterGeneratorSpi$object	_jc_java_security_AlgorithmParameterGeneratorSpi$object;

typedef const struct _jc_java_security_AlgorithmParameterGeneratorSpi$vmethods	_jc_java_security_AlgorithmParameterGeneratorSpi$vmethods;
typedef const struct _jc_java_security_AlgorithmParameterGeneratorSpi$vtable	_jc_java_security_AlgorithmParameterGeneratorSpi$vtable;
typedef const struct _jc_java_security_AlgorithmParameterGeneratorSpi$vtype	_jc_java_security_AlgorithmParameterGeneratorSpi$vtype;

// Constructors
extern void _jc_java_security_AlgorithmParameterGeneratorSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_security_AlgorithmParameters$object *_jc_java_security_AlgorithmParameterGeneratorSpi$method$engineGenerateParameters$c500aa80c3b5d11e(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_AlgorithmParameterGeneratorSpi$method$engineInit$ce17ad6b3fc98d82(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_AlgorithmParameterGeneratorSpi$method$engineInit$5af33bc7d4d69573(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_AlgorithmParameterGeneratorSpi$method_info$engineGenerateParameters$c500aa80c3b5d11e;
extern _jc_method _jc_java_security_AlgorithmParameterGeneratorSpi$method_info$engineInit$ce17ad6b3fc98d82;
extern _jc_method _jc_java_security_AlgorithmParameterGeneratorSpi$method_info$engineInit$5af33bc7d4d69573;

// Virtual methods structure
struct _jc_java_security_AlgorithmParameterGeneratorSpi$vmethods {
	struct _jc_java_security_AlgorithmParameters$object	*(*engineGenerateParameters$c500aa80c3b5d11e)(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *) _JC_JCNI_ATTR;
	void	(*engineInit$ce17ad6b3fc98d82)(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*engineInit$5af33bc7d4d69573)(_jc_env *, struct _jc_java_security_AlgorithmParameterGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_AlgorithmParameterGeneratorSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_AlgorithmParameterGeneratorSpi$vmethods	java_security_AlgorithmParameterGeneratorSpi;
};

// Vtype
struct _jc_java_security_AlgorithmParameterGeneratorSpi$vtype {
	_jc_type			type;
	_jc_java_security_AlgorithmParameterGeneratorSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AlgorithmParameterGeneratorSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_AlgorithmParameterGeneratorSpi$refs {
    _jc_java_security_AlgorithmParameterGeneratorSpi$sub_refs	java_security_AlgorithmParameterGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AlgorithmParameterGeneratorSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_AlgorithmParameterGeneratorSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_AlgorithmParameterGeneratorSpi$sub_nonrefs	java_security_AlgorithmParameterGeneratorSpi;
};

// Object instance structure
struct _jc_java_security_AlgorithmParameterGeneratorSpi$object {
	_jc_java_security_AlgorithmParameterGeneratorSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AlgorithmParameterGeneratorSpi$vtype	*vtype;
	_jc_java_security_AlgorithmParameterGeneratorSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AlgorithmParameterGeneratorSpi$vtype _jc_java_security_AlgorithmParameterGeneratorSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AlgorithmParameterGeneratorSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AlgorithmParameterGeneratorSpi$class_object;

#endif	/* _JC_java_security_AlgorithmParameterGeneratorSpi_H_ */
